@@ -35,7 +35,7 @@ fetchPedonPC <- function(dsn) {
 	depths(f) <- pedon_id ~ hzdept + hzdepb
 	
 	# move site data into @site
-	site(f) <- ~ peiid + site_id + siteiid + sampled_as + correlated_as + hillslope_pos + x + y + datum + elev + slope + aspect + plantassocnm + bedrckdepth + bedrock_kind + bedrock_hardness + describer + psctopdepth + pscbotdepth + part_size_class + tax_subgroup + obs_date + pedon_purpose + pedon_type + pedlabsampnum
+	site(f) <- ~ peiid + site_id + siteiid + hillslope_pos + x + y + datum + elev + slope + aspect + plantassocnm + bedrckdepth + bedrock_kind + bedrock_hardness + describer + psctopdepth + pscbotdepth + obs_date + pedon_purpose + pedon_type + pedlabsampnum
 	
 	# 5. convert colors... in the presence of missing color data
 	f$soil_color <- rep(NA, times=nrow(horizons(f)))
@@ -45,11 +45,17 @@ fetchPedonPC <- function(dsn) {
 	# 6. merge-in extended data:
 	# replace horizons with hz + fragment summary
 	horizons(f) <- join(horizons(f), extended_data$frag_summary, by='phiid', type='left')
+	
 	# add diagnostic boolean data into @site
 	site(f) <- extended_data$diagHzBoolean
+	
 	# load diagnostic horizons into @diagnostic: note that this requires one additional join
 	diagnostic_hz(f) <- join(site(f)[, c('pedon_id','peiid')], extended_data$diagnostic, by='peiid', type='left')
 	
+	# load best-guess optimal records from taxhistory
+	best.tax.data <- ddply(extended_data$taxhistory, 'peiid', pickBestTaxHistory)
+	site(f) <- best.tax.data
+	
 	# 7. mention bad pedons
 	if(length(bad.pedon.ids) > 0)
 		cat(paste('horizon errors in:', paste(bad.pedon.ids, collapse=','), '\n'))
