@@ -9,7 +9,7 @@ FROM (
 	ORDER BY phiid, dbo.phcolor.colormoistst;"
   
 	# setup connection to our local NASIS database
-	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='Re@d0n1y') 
+	channel <- odbcConnect('nasis_local', uid='NasisSqlRO', pwd='nasisRe@d0n1y') 
 	
 	# exec query
 	d <- sqlQuery(channel, q, stringsAsFactors=FALSE)
